==> mm_std-0.1.13-py3-none-any.whl: mm_std/print_.py <==
import sys
from collections.abc import Callable
from enum import Enum, unique
from typing import Any, NoReturn

import rich
from rich.console import Console
from rich.table import Table

from mm_std.json_ import json_dumps


@unique
class PrintFormat(str, Enum):
    PLAIN = "plain"
    TABLE = "table"
    JSON = "json"


def fatal(message: str, code: int = 1) -> NoReturn:
    print(message, file=sys.stderr)  # noqa: T201
    sys.exit(code)


def print_console(*messages: object, print_json: bool = False, default: Callable[[object], str] | None = None) -> None:
    if len(messages) == 1:
        message = messages[0]
        if isinstance(message, str):
            print(message)  # noqa: T201
        elif print_json:
            rich.print_json(json_dumps(message, default=default))
        else:
            rich.print(message)
    else:
        rich.print(messages)


def print_plain(messages: object, print_format: PrintFormat | None = None) -> None:
    if print_format is None or print_format == PrintFormat.PLAIN:
        print(messages)  # noqa: T201


def print_json(data: object, default: Callable[[object], str] | None = None, print_format: PrintFormat | None = None) -> None:
    if print_format is None or print_format == PrintFormat.JSON:
        rich.print_json(json_dumps(data, default=default))


def print_table(title: str, columns: list[str], rows: list[list[Any]], print_format: PrintFormat | None = None) -> None:
    if print_format is None or print_format == PrintFormat.TABLE:
        table = Table(*columns, title=title)
        for row in rows:
            table.add_row(*(str(cell) for cell in row))
        console = Console()
        console.print(table)

==> mm_std-0.1.14-py3-none-any.whl: mm_std/print_.py <==
import sys
from collections.abc import Callable
from enum import Enum, unique
from typing import Any, NoReturn

import rich
from rich.console import Console
from rich.table import Table

from mm_std.json_ import json_dumps


@unique
class PrintFormat(str, Enum):
    PLAIN = "plain"
    TABLE = "table"
    JSON = "json"


def fatal(message: str, code: int = 1) -> NoReturn:
    print(message, file=sys.stderr)  # noqa: T201
    sys.exit(code)


def print_console(*messages: object, print_json: bool = False, default: Callable[[object], str] | None = None) -> None:
    if len(messages) == 1:
        message = messages[0]
        if isinstance(message, str):
            print(message)  # noqa: T201
        elif print_json:
            rich.print_json(json_dumps(message, default=default))
        else:
            rich.print(message)
    else:
        rich.print(messages)


def print_plain(messages: object, print_format: PrintFormat | None = None) -> None:
    if print_format is None or print_format == PrintFormat.PLAIN:
        print(messages)  # noqa: T201


def print_json(data: object, default: Callable[[object], str] | None = str, print_format: PrintFormat | None = None) -> None:
    if print_format is None or print_format == PrintFormat.JSON:
        rich.print_json(json_dumps(data, default=default))


def print_table(title: str, columns: list[str], rows: list[list[Any]], print_format: PrintFormat | None = None) -> None:
    if print_format is None or print_format == PrintFormat.TABLE:
        table = Table(*columns, title=title)
        for row in rows:
            table.add_row(*(str(cell) for cell in row))
        console = Console()
        console.print(table)
